import { bitable } from "@lark-opdev/block-bitable-api";
import { FC, useEffect } from "react";
import { useAsync } from "react-async-hook";
import { getCurrentTag, setAmount, setChecked} from "./utils";
import {
  Typography,
  Tag,
  Button,
  Divider,
  Space,
  Toast,
  InputNumber,
} from "@douyinfe/semi-ui";

const { Title, Text } = Typography;

const defaultTask = {
  tag: "",
  userName: "",
  amount: 0,
  checked: false
};

export const App = () => {
  const task = useAsync(getCurrentTag, []);
  const { tag, userName, amount, checked } = task.result ?? defaultTask;

  // 切换上下一条记录时，触发 SelectionChange
  useEffect(() => {
    return bitable.base.onSelectionChange(({ data }) =>
      task.execute()
    );
  }, []);

  const amountMinus = () => {
    setAmount(amount - 1 > 0 ? amount - 1 : 0)
      .then(() => task.execute())
      .then(() => Toast.success("amountMinus成功"))
      .catch(() => Toast.error("amountMinus失败"));
  };
  const amountPlus = () => {
    setAmount(amount + 1)
      .then(() => task.execute())
      .then(() => Toast.success("amountPlus成功"))
      .catch(() => Toast.error("amountPlus失败"));
  };

  const togglechecked = () => {
    setChecked(true)
      .then(() => task.execute())
      .then(() => Toast.success("amountPlus成功"))
      .catch(() => Toast.error("amountPlus失败"));
  };

  if (task.loading) return <div>loading</div>;
  if (task.error) return <div>error: {task.error.message}</div>;

  return (
    <PureTaskComponment
      tag={tag}
      userName={userName}
      amount={amount}
      checked={checked}
      amountMinus={amountMinus}
      amountPlus={amountPlus}
      togglechecked={togglechecked}
    />
  );
};

interface PureTaskComponmentProps {
  tag: string;
  userName: string;
  amount: number;
  checked: boolean;
  amountMinus: () => void;
  amountPlus: () => void;
  togglechecked: () => void;
}

const PureTaskComponment: FC<PureTaskComponmentProps> = ({
  tag,
  userName,
  amount,
  checked,
  togglechecked,
  amountMinus,
  amountPlus,
}) => {
  return (
    <Space vertical align="start">
      <div>
        <Title heading={2}>Check</Title>
      </div>
      <div>
        <Text>描述：</Text>
        <Text>{tag}</Text>
      </div>
      <div>
        <Text>amount:</Text>
        <InputNumber
          id="amount"
          color={checked ? "green" : "yellow"}>
          {amount}
        </InputNumber>
      </div>
      <Divider />
      <div>
        <Button
          type="warning"
          onClick={amountMinus}
          disabled={amount <= 0}
          circle={true}
        >
          减少
        </Button>
        <Button
          type="primary"
          onClick={amountPlus}
        >
          增加
        </Button>
      </div>
      <div>
        <Text>执行人：</Text>
        <Text>{userName}</Text>
      </div>
      <div>
        <Button
          type="primary"
          onClick={togglechecked}
        >
          {checked ? "取消" : "确认"}
        </Button>
      </div>
    </Space>
  );
};
